diff --git a/src/Gui/DlgReportView.ui b/src/Gui/DlgReportView.ui
index e2aef52db7..aa0a5ff93f 100644
--- a/src/Gui/DlgReportView.ui
+++ b/src/Gui/DlgReportView.ui
@@ -11,7 +11,7 @@
- Output window
+ Report view
-
diff --git a/src/Gui/DlgReportViewImp.h b/src/Gui/DlgReportViewImp.h
index ebecb65fdb..98d9b4c14c 100644
--- a/src/Gui/DlgReportViewImp.h
+++ b/src/Gui/DlgReportViewImp.h
@@ -32,7 +32,7 @@ namespace Dialog {
class Ui_DlgReportView;
/** The DlgReportViewImp class implements the available settings for the
- * report output window to change.
+ * Report View to change.
* \author Werner Mayer
*/
class DlgReportViewImp : public PreferencePage
diff --git a/src/Gui/PythonConsolePy.cpp b/src/Gui/PythonConsolePy.cpp
index e8dd6786a2..4845a795b5 100644
--- a/src/Gui/PythonConsolePy.cpp
+++ b/src/Gui/PythonConsolePy.cpp
@@ -163,7 +163,7 @@ Py::Object PythonStderr::isatty()
void OutputStdout::init_type()
{
behaviors().name("OutputStdout");
- behaviors().doc("Redirection of stdout to FreeCAD's output window");
+ behaviors().doc("Redirection of stdout to FreeCAD's report view");
// you must have overwritten the virtual functions
behaviors().supportRepr();
add_varargs_method("write",&OutputStdout::write,"write()");
@@ -228,7 +228,7 @@ Py::Object OutputStdout::isatty()
void OutputStderr::init_type()
{
behaviors().name("OutputStderr");
- behaviors().doc("Redirection of stdout to FreeCAD's output window");
+ behaviors().doc("Redirection of stdout to FreeCAD's report view");
// you must have overwritten the virtual functions
behaviors().supportRepr();
add_varargs_method("write",&OutputStderr::write,"write()");
diff --git a/src/Gui/PythonConsolePy.h b/src/Gui/PythonConsolePy.h
index 1b1c290b02..e4db9a58e9 100644
--- a/src/Gui/PythonConsolePy.h
+++ b/src/Gui/PythonConsolePy.h
@@ -86,7 +86,7 @@ public:
/**
* Python class for redirection of stdout to FreeCAD's output
* console window. This allows to report all Python output to
- * the output window which simplifies debugging scripts.
+ * the report view which simplifies debugging scripts.
* @see PythonStdout
* @see PythonStderr
* @author Werner Mayer
@@ -109,7 +109,7 @@ public:
/**
* Python class for redirection of stderr to FreeCAD's output
* console window. This allows to report all Python errors to
- * the output window which simplifies error tracking.
+ * the report view which simplifies error tracking.
* @see PythonStdout
* @see PythonStderr
* @author Werner Mayer
diff --git a/src/Gui/ReportView.cpp b/src/Gui/ReportView.cpp
index 1a469143f7..023edd907b 100644
--- a/src/Gui/ReportView.cpp
+++ b/src/Gui/ReportView.cpp
@@ -69,7 +69,7 @@ ReportView::ReportView( QWidget* parent )
tabLayout->addWidget( tabWidget, 0, 0 );
// create the output window
tabOutput = new ReportOutput();
tabOutput->setWindowTitle(tr("Output"));
tabOutput->setWindowIcon(BitmapFactory().pixmap("MacroEditor"));
@@ -571,7 +571,7 @@ void ReportOutput::contextMenuEvent ( QContextMenuEvent * e )
errAct->setChecked(bErr);
auto showOnMenu = new QMenu (optionMenu);
- showOnMenu->setTitle(tr("Show output window on"));
+ showOnMenu->setTitle(tr("Show Report view on"));
optionMenu->addMenu(showOnMenu);
QAction* showNormAct = showOnMenu->addAction(tr("Normal messages"), this, SLOT(onToggleShowReportViewOnNormalMessage()));
@@ -69,7 +69,7 @@ ReportView::ReportView( QWidget* parent )
tabLayout->addWidget( tabWidget, 0, 0 );
- // create the output window
+ // create the output window for 'Report view'
tabOutput = new ReportOutput();
tabOutput->setWindowTitle(tr("Output"));
diff --git a/src/Gui/ReportView.h b/src/Gui/ReportView.h
index ff6989fe3c..0a726d9d6b 100644
--- a/src/Gui/ReportView.h
+++ b/src/Gui/ReportView.h
@@ -59,7 +59,7 @@ protected:
private:
QTabWidget* tabWidget;
- ReportOutput* tabOutput; /**< Output window */
+ ReportOutput* tabOutput; /**< Output 'Report view' window */
PythonConsole* tabPython; /**< Python console */
};
@@ -118,7 +118,7 @@ private:
//@}
};
/** Output window to show messages.
* @see Base::ILogger
* @see QTextEdit
* \author Werner Mayer
@@ -118,7 +118,7 @@ private:
//@}
};
-/** Output window to show messages.
+/** Output window 'Report view' to show messages.
* @see Base::ILogger
* @see QTextEdit